Struct ZxdgOutputV1
pub struct ZxdgOutputV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
compositor logical output region
An xdg_output describes part of the compositor geometry.
This typically corresponds to a monitor that displays part of the compositor space.
For objects version 3 onwards, after all xdg_output properties have been sent (when the object is created and when properties are updated), a wl_output.done event is sent. This allows changes to the output properties to be seen as atomic, even if they happen via multiple events.
See also the Event enum for this interface.
Implementations
impl ZxdgOutputV1
impl ZxdgOutputV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the xdg_output object
Using this request a client can tell the server that it is not going to use the xdg_output object anymore.